package com.bweb.controller;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.DateUtil;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.entity.HighApprove;
import com.hai.entity.HighCouponHandsel;
import com.hai.entity.HighMerchant;
import com.hai.model.HighCouponModel;
import com.hai.model.ResponseData;
import com.hai.model.UserInfoModel;
import com.hai.service.HighApproveService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Date;

/**
 * @ClassName HighApproveController
 * @Description: 审批操作
 * @Author 胡锐
 * @Date 2021/3/16
 **/
@Controller
@RequestMapping(value = "/coupon")
@Api(value = "卡卷接口")
public class HighApproveController {

    private static Logger log = LoggerFactory.getLogger(HighApproveController.class);

    @Autowired
    private UserCenter userCenter;

    @Resource
    private HighApproveService highApproveService;

    @RequestMapping(value="/approveProcessed",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "审批")
    public ResponseData approveProcessed(@RequestBody String reqBody, HttpServletRequest request) {
        try {
            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();

            JSONObject jsonObject = JSONObject.parseObject(reqBody);
            Long approveId = jsonObject.getLong("approveId");
            Integer status = jsonObject.getInteger("status");
            String remarks = jsonObject.getString("remarks");
            if(approveId == null || status == null) {
                log.error("HighCouponController -> approveProcessed() error!","参数错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            // 查询审批记录
            HighApprove approve = highApproveService.getApproveById(approveId);
            if (approve == null) {
                log.error("HighCouponController -> approveProcessed() error!","未找到审批记录");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.NOT_FOUND_APPROVE, "");
            }
            if (approve.getStatus() != 1) {
                log.error("HighCouponController -> approveProcessed() error!","审批已处理");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.APPROVE_PROCESSED, "");
            }

            approve.setRemarks(remarks);
            approve.setUpdateTime(new Date());
            approve.setApproveOperatorId(userInfoModel.getSecUser().getId());
            approve.setApproveOperatorName(userInfoModel.getSecUser().getUserName());
            highApproveService.approveProcessed(approve);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighCouponController -> approveProcessed() error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }
}
